##  Inline Editing
In the table view, you can do inline editing, allowing you to quickly update and modify information for multiple fact sheets in one go. Click Edit at the top right of the table to activate inline editing. You can do the following actions:
  * Add or update content: Click on any cell to add or edit its value directly, including relations.
  * Copy and paste: Copy values from one cell to another using the right-click menu or your system's default shortcuts for copy and paste functions.
  * Autofill cells: Autofill cells by dragging the handle at the bottom right corner of the selected cell downwards.
  * Fill date fields from the calendar: Double-click on date fields, such as lifecycles, and choose a date from the calendar overlay that appears.
  * Choose values for multi-select fields: Double-click on a multi-select field to open a dropdown menu, then choose from the available values.


Once you have made changes to the fact sheets in the inventory, the total count of changes is shown at the top of the inventory table. All the cells you changed are highlighted with a change in color, making it easy to review. If everything is correct, save the changes by clicking the Save button in the top right corner.
![Inline Editing in Table View Mode](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749045e7a441014a788f3a51893725d_LowRes.gif)
Inline Editing in Table View Mode
